@@ -47,7 +47,7 @@ class NxPyDocs():
             for single_command in self.supported_templates:
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
-                parsed_json = json.dumps(command_output, indent=4, sort_keys=True)
+                parsed_json = json.loads(command_output, indent=4, sort_keys=True)
                 pp.pprint(parsed_json)
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
@@ -57,7 +57,7 @@ class NxPyDocs():
         else:
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
-                parsed_json = json.dumps(command_output, indent=4, sort_keys=True)
+                parsed_json = json.loads(command_output, indent=4, sort_keys=True)
                 pp.pprint(parsed_json)
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
@@ -85,14 +85,14 @@ class NxPyDocs():
             self.all_files(parsed_json)
 
     def json_file(self, parsed_json):
-        with open(f'{self.command}.json', 'w') as f:
+        with open(' %s.json' % self.command, 'w') as f:
             f.write(parsed_json)
         click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
         fg='green')
 
     def yaml_file(self, parsed_json):
         clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
-        with open(f'{self.command}.yaml', 'w') as f:
+        with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
         click.secho("YAML file created at %s / %s.yaml" % (sys.path[0],self.command),
         fg='green')
@@ -100,10 +100,10 @@ class NxPyDocs():
     def html_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
-        html_template = env.get_template(f'html.j2')
+        html_template = env.get_template('html.j2')
         html_output = html_template.render(command = self.command,
             data_to_template=json.loads(parsed_json))
-        with open(f'{self.command}.html', 'w') as f:
+        with open('%s.html' % self.command, 'w') as f:
             f.write(html_output)
         click.secho("HTML file created at %s / %s.html" % (sys.path[0],self.command),
             fg='green')
@@ -111,10 +111,10 @@ class NxPyDocs():
     def markdown_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
-        markdown_template = env.get_template(f'{self.os} md.j2')
+        markdown_template = env.get_template('md.j2')
         markdown_output = markdown_template.render(command = self.command,
             data_to_template=json.loads(parsed_json))
-        with open(f'{self.command}.md', 'w') as f:
+        with open('%s.md' % self.command, 'w') as f:
             f.write(markdown_output)
         click.secho("Markdown file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
@@ -122,11 +122,11 @@ class NxPyDocs():
     def csv_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
-        csv_template = env.get_template(f'{self.os} csv.j2')
+        csv_template = env.get_template('csv.j2')
         csv_output = csv_template.render(command = self.command,
             data_to_template=json.loads(parsed_json),
             hostname=self.hostname)
-        with open(f'{self.command}.csv', 'w') as f:
+        with open('%s.csv' % self.command, 'w') as f:
             f.write(csv_output)
         click.secho("CSV file created at %s / %s.csv" % (sys.path[0],self.command),
             fg='green')
@@ -134,11 +134,11 @@ class NxPyDocs():
     def mindmap_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
-        mindmap_template = env.get_template(f'{self.os} mindmap.j2')
+        mindmap_template = env.get_template('mindmap.j2')
         mindmap_output = mindmap_template.render(command = self.command,
             data_to_template=json.loads(parsed_json),
             hostname=self.hostname)
-        with open(f'{self.command} mindmap.md', 'w') as f:
+        with open('%s mindmap.md' % self.command, 'w') as f:
             f.write(mindmap_output)
         click.secho(
             "Mindmap file created at %s / %s.md" % (sys.path[0],self.command),
